@@ -7,7 +7,6 @@ use std::slice::{Iter, IterMut};
 use crossterm::terminal;
 #[cfg(feature = "tty")]
 use crossterm::tty::IsTty;
-use strum::IntoEnumIterator;
 
 use crate::cell::Cell;
 use crate::column::Column;
@@ -21,7 +20,7 @@ use crate::utils::build_table;
 ///
 /// There also exists a representation of a [Column].
 /// Columns are automatically created when adding rows to a table.
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct Table {
     pub(crate) columns: Vec<Column>,
     style: HashMap<TableComponent, char>,
@@ -29,6 +28,7 @@ pub struct Table {
     pub(crate) rows: Vec<Row>,
     pub(crate) arrangement: ContentArrangement,
     pub(crate) delimiter: Option<char>,
+    pub(crate) truncation_indicator: String,
     #[cfg(feature = "tty")]
     no_tty: bool,
     #[cfg(feature = "tty")]
@@ -63,6 +63,7 @@ impl Table {
             rows: Vec::new(),
             arrangement: ContentArrangement::Disabled,
             delimiter: None,
+            truncation_indicator: "...".to_string(),
             #[cfg(feature = "tty")]
             no_tty: false,
             #[cfg(feature = "tty")]
@@ -105,7 +106,6 @@ impl Table {
     /// let header = Row::from(vec!["Header One", "Header Two"]);
     /// table.set_header(header);
     /// ```
-
     pub fn set_header<T: Into<Row>>(&mut self, row: T) -> &mut Self {
         let row = row.into();
         self.autogenerate_columns(&row);
@@ -316,6 +316,15 @@ impl Table {
         self
     }
 
+    /// Set the truncation indicator for cells that are too long to be displayed.
+    ///
+    /// Set it to "…" for example to use an ellipsis that only takes up one character.
+    pub fn set_truncation_indicator(&mut self, indicator: &str) -> &mut Self {
+        self.truncation_indicator = indicator.to_string();
+
+        self
+    }
+
     /// In case you are sure you don't want export tables to a tty or you experience
     /// problems with tty specific code, you can enforce a non_tty mode.
     ///
@@ -570,7 +579,6 @@ impl Table {
     /// let mut table = Table::new();
     /// assert_eq!(table.style(TopLeftCorner), Some('+'));
     /// ```
-
     pub fn style(&mut self, component: TableComponent) -> Option<char> {
         self.style.get(&component).copied()
     }
@@ -757,7 +765,7 @@ impl Table {
     }
 
     pub(crate) fn style_exists(&self, component: TableComponent) -> bool {
-        self.style.get(&component).is_some()
+        self.style.contains_key(&component)
     }
 
     /// Autogenerate new columns, if a row is added with more cells than existing columns.
@@ -859,7 +867,7 @@ mod tests {
     #[test]
     fn test_column_generation() {
         let mut table = Table::new();
-        table.set_header(&vec!["thr", "four", "fivef"]);
+        table.set_header(vec!["thr", "four", "fivef"]);
 
         // When adding a new row, columns are automatically generated
         assert_eq!(table.columns.len(), 3);
@@ -867,11 +875,11 @@ mod tests {
         assert_eq!(table.column_max_content_widths(), vec![3, 4, 5]);
 
         // When adding a new row, the max content width is updated accordingly
-        table.add_row(&vec!["four", "fivef", "very long text with 23"]);
+        table.add_row(vec!["four", "fivef", "very long text with 23"]);
         assert_eq!(table.column_max_content_widths(), vec![4, 5, 22]);
 
         // Now add a row that has column lines. The max content width shouldn't change
-        table.add_row(&vec!["", "", "shorter"]);
+        table.add_row(vec!["", "", "shorter"]);
         assert_eq!(table.column_max_content_widths(), vec![4, 5, 22]);
 
         println!("{table}");
